Py4JMethod (py4j-java 0.10.9.4 API)
Date: 2022-03-16

py4j.model

## Class Py4JMethod

- java.lang.Object
- - py4j.model.Py4JMember
  - - py4j.model.Py4JMethod

- All Implemented Interfaces:
    java.lang.Comparable<Py4JMember>

      public class Py4JMethod
      extends Py4JMember

  Model of a Java method used to create a help page.

- - ### Constructor Summary

    Constructors
    Constructor and Description
    `Py4JMethod(java.lang.String name, java.lang.String javadoc, java.util.List<java.lang.String> parameterTypes, java.util.List<java.lang.String> parameterNames, java.lang.String returnType, java.lang.String container)`

  - ### Method Summary

    All Methods Static Methods Instance Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `static Py4JMethod` | `buildMethod(java.lang.reflect.Method method)`
    `java.lang.String` | `getContainer()`
    `java.util.List<java.lang.String>` | `getParameterNames()`
    `java.util.List<java.lang.String>` | `getParameterTypes()`
    `java.lang.String` | `getReturnType()`
    `java.lang.String` | `getSignature(boolean shortName)`

    - ### Methods inherited from class py4j.model.Py4JMember

      `compareTo, equals, getJavadoc, getName, hashCode`

    - ### Methods inherited from class java.lang.Object

      `clone, finalize, getClass, notify, notifyAll, toString, wait, wait, wait`

- - ### Constructor Detail

    - #### Py4JMethod

          public Py4JMethod(java.lang.String name,
                            java.lang.String javadoc,
                            java.util.List<java.lang.String> parameterTypes,
                            java.util.List<java.lang.String> parameterNames,
                            java.lang.String returnType,
                            java.lang.String container)

  - ### Method Detail

    - #### buildMethod

          public static final Py4JMethod buildMethod(java.lang.reflect.Method method)

    - #### getContainer

          public java.lang.String getContainer()

    - #### getParameterNames

          public java.util.List<java.lang.String> getParameterNames()

    - #### getParameterTypes

          public java.util.List<java.lang.String> getParameterTypes()

    - #### getReturnType

          public java.lang.String getReturnType()

    - #### getSignature

          public java.lang.String getSignature(boolean shortName)

      Specified by:
        `getSignature` in class `Py4JMember`